/*
 * Copyright (c) 2011-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef ApplicationUI_HPP_
#define ApplicationUI_HPP_

#include <QObject>
#include <QSettings>
#include <bb/system/InvokeManager>
#include <bb/system/InvokeRequest>

namespace bb
{
    namespace cascades
    {
        class LocaleHandler;
    }
}

class QTranslator;

/*!
 * @brief Application UI object
 *
 * Use this object to create and init app UI, to create context objects, to register the new meta types etc.
 */
class ApplicationUI : public QObject
{
    Q_OBJECT
public:
    ApplicationUI();
    virtual ~ApplicationUI() {}

    Q_INVOKABLE QVariant setting(const QString &key);
    Q_INVOKABLE void setSetting(const QString &key, const QString &value);
    Q_INVOKABLE QString appversion();
    Q_INVOKABLE void copyText(QString text);
    Q_INVOKABLE void showImage(const QString &filename);

Q_SIGNALS:
    void createPost(QByteArray text);

private slots:
    void onSystemLanguageChanged();
    void onInvoke(const bb::system::InvokeRequest &request);

private:
    QTranslator* m_pTranslator;
    bb::cascades::LocaleHandler* m_pLocaleHandler;
    QSettings* m_appSettings;
    bb::system::InvokeManager *invokeManager;
};

#endif /* ApplicationUI_HPP_ */
